@@ -1,6 +1,8 @@
 mod cholesky;
+mod generalized_eigenvalues;
 mod lu;
 mod qr;
+mod qz;
 mod real_eigensystem;
 mod schur;
 mod svd;
